==> libffado_2.0.0.orig.tar.gz: libffado-2.0.0/src/libieee1394/vendor_model_ids.h <==
/*
 * Copyright (C) 2005-2008 by Pieter Palmers
 *
 * This file is part of FFADO
 * FFADO = Free Firewire (pro-)audio drivers for linux
 *
 * FFADO is based upon FreeBoB
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef VENDOR_MODEL_IDS
#define VENDOR_MODEL_IDS

#define FW_VENDORID_TERRATEC     0x000aac
#define FW_VENDORID_MACKIE       0x00000f
#define FW_VENDORID_APOGEE       0x0003db
#define FW_VENDORID_BRIDGECO     0x0007f5
#define FW_VENDORID_PRESONUS     0x000a92
#define FW_VENDORID_ESI          0x000f1b
#define FW_VENDORID_FOCUSRITE    0x00130e
#define FW_VENDORID_EDIROL       0x0040ab
#define FW_VENDORID_MAUDIO       0x000d6c
#define FW_VENDORID_ECHO         0x001486
#define FW_VENDORID_RME          0x000a35
#define FW_VENDORID_MOTU         0x0001f2
#define FW_VENDORID_TCAT         0x000166

// this is the one we assign ourselves
// maybe once we can get a real one :)
#define FW_VENDORID_FFADO        0x0B0001


#endif /* VENDOR_MODEL_IDS */

==> libffado_2.4.4.orig.tar.gz: libffado-2.4.4/src/libieee1394/vendor_model_ids.h <==
/*
 * Copyright (C) 2005-2008 by Pieter Palmers
 *
 * This file is part of FFADO
 * FFADO = Free Firewire (pro-)audio drivers for linux
 *
 * FFADO is based upon FreeBoB
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef VENDOR_MODEL_IDS
#define VENDOR_MODEL_IDS

#define FW_VENDORID_TERRATEC     0x000aac
#define FW_VENDORID_MACKIE       0x00000f
#define FW_VENDORID_APOGEE       0x0003db
#define FW_VENDORID_BRIDGECO     0x0007f5
#define FW_VENDORID_PRESONUS     0x000a92
#define FW_VENDORID_ESI          0x000f1b
#define FW_VENDORID_FOCUSRITE    0x00130e
#define FW_VENDORID_EDIROL       0x0040ab
#define FW_VENDORID_MAUDIO       0x000d6c
#define FW_VENDORID_ECHO         0x001486
#define FW_VENDORID_RME          0x000a35
#define FW_VENDORID_MOTU         0x0001f2
#define FW_VENDORID_TCAT         0x000166
#define FW_VENDORID_ALESIS       0x000595
#define FW_VENDORID_WEISS        0x001C6A
#define FW_VENDORID_STANTON      0x001260
#define FW_VENDORID_DNR          0x000F64
#define FW_VENDORID_YAMAHA       0x00a0de

// this is the one we assign ourselves
// maybe once we can get a real one :)
#define FW_VENDORID_FFADO        0x0B0001

#endif /* VENDOR_MODEL_IDS */
